Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type InformerPair ¶
type InformerPair struct {
// GenericLister is a lister that helps list generic resource.
// All objects returned here must be treated as read-only.
Lister cache.GenericLister
// Informer provides add and get Indexers ability based on SharedInformer.
Informer cache.SharedIndexInformer
}
InformerPair include informer and lister for resource
type KubeEdgeCustomInformer ¶
type KubeEdgeCustomInformer interface {
EdgeNode() cache.SharedIndexInformer
}
type Manager ¶
type Manager interface {
// GetKubeInformerFactory return kubernetes built-in resources InformerFactory
GetKubeInformerFactory() k8sinformer.SharedInformerFactory
// GetKubeEdgeInformerFactory return KubeEdge CRD resources InformerFactory
GetKubeEdgeInformerFactory() edgeinformers.SharedInformerFactory
// GetDynamicInformerFactory return third-party CRD resources InformerFactory
GetDynamicInformerFactory() dynamicinformer.DynamicSharedInformerFactory
// KubeEdgeCustomInformer return custom informer
KubeEdgeCustomInformer
// Start start all InformerFactory
Start(stopCh <-chan struct{})
// GetInformerPair return InformerPair for the given GVR
GetInformerPair(gvr schema.GroupVersionResource) (*InformerPair, error)
// GetLister return cached lister for the given GVR
GetLister(gvr schema.GroupVersionResource) (cache.GenericLister, error)
}
func GetInformersManager ¶
func GetInformersManager() Manager
func NewFakeInformerManager ¶
func NewFakeInformerManager() Manager
Click to show internal directories.
Click to hide internal directories.