Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Controller ¶
type Controller struct {
client.Client
runtime.Serializer
overridemanager.Overrider
statusmanager.StatusManager
UseServerSideApply bool
ReconcileTriggerChan chan event.GenericEvent
}
Controller is to sync EdgeApplication.
func NewController ¶
func NewController(ctx context.Context, cli client.Client, serializer runtime.Serializer, mgr manager.Manager) *Controller
func (*Controller) Reconcile ¶
func (c *Controller) Reconcile(ctx context.Context, req controllerruntime.Request) (controllerruntime.Result, error)
Reconcile performs a full reconciliation for the object referred to by the Request. The Controller will requeue the Request to be processed again if an error is non-nil or Result.Requeue is true, otherwise upon completion it will remove the work from the queue.
func (*Controller) SetupWithManager ¶
func (c *Controller) SetupWithManager(_ctx context.Context, mgr controllerruntime.Manager) error
SetupWithManager creates a controller and register to controller manager.
Directories
¶
| Path | Synopsis |
|---|---|
|
CHANGELOG KubeEdge Authors: - This File is derived from github.com/karmada-io/karmada/pkg/util/overridemanager/argsoverride.go - refactor argsOverrider as a struct that implements the Overrider interface
|
CHANGELOG KubeEdge Authors: - This File is derived from github.com/karmada-io/karmada/pkg/util/overridemanager/argsoverride.go - refactor argsOverrider as a struct that implements the Overrider interface |
Click to show internal directories.
Click to hide internal directories.